from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, File, String, Boolean

Mageck_Mle_V0_1_0 = CommandToolBuilder(tool="mageck_mle", base_command=["mageck", "mle"], inputs=[ToolInput(tag="in_count_table", input_type=Int(optional=True), prefix="--count-table", doc=InputDocumentation(doc="Provide a tab-separated count table. Each line in the\ntable should include sgRNA name (1st column), target\ngene (2nd column) and read counts in each sample.")), ToolInput(tag="in_design_matrix", input_type=File(optional=True), prefix="--design-matrix", doc=InputDocumentation(doc="Provide a design matrix, either a file name or a\nquoted string of the design matrix. For example,\n'1,1;1,0'. The row of the design matrix must match the\norder of the samples in the count table (if --include-\nsamples is not specified), or the order of the samples\nby the --include-samples option.")), ToolInput(tag="in_day_zero_label", input_type=Int(optional=True), prefix="--day0-label", doc=InputDocumentation(doc="Specify the label for control sample (usually day 0 or\nplasmid). For every other sample label, the MLE module\nwill treat it as a single condition and generate an\ncorresponding design matrix.")), ToolInput(tag="in_output_prefix", input_type=File(optional=True), prefix="--output-prefix", doc=InputDocumentation(doc="The prefix of the output file(s). Default sample1.")), ToolInput(tag="in_include_samples", input_type=File(optional=True), prefix="--include-samples", doc=InputDocumentation(doc="Specify the sample labels if the design matrix is not\ngiven by file in the --design-matrix option. Sample\nlabels are separated by ',', and must match the labels\nin the count table.")), ToolInput(tag="in_beta_labels", input_type=Int(optional=True), prefix="--beta-labels", doc=InputDocumentation(doc="Specify the labels of the variables (i.e., beta), if\nthe design matrix is not given by file in the\n--design-matrix option. Should be separated by ',',\nand the number of labels must equal to (# columns of\ndesign matrix), including baseline labels. Default\nvalue: 'bata_0,beta_1,beta_2,...'.")), ToolInput(tag="in_control_sg_rna", input_type=String(optional=True), prefix="--control-sgrna", doc=InputDocumentation(doc="A list of control sgRNAs for normalization and for\ngenerating the null distribution of RRA.")), ToolInput(tag="in_control_gene", input_type=String(optional=True), prefix="--control-gene", doc=InputDocumentation(doc="A list of genes whose sgRNAs are used as control\nsgRNAs for normalization and for generating the null\ndistribution of RRA.")), ToolInput(tag="in_cnv_norm", input_type=Int(optional=True), prefix="--cnv-norm", doc=InputDocumentation(doc="A matrix of copy number variation data across cell\nlines to normalize CNV-biased sgRNA scores prior to\ngene ranking.")), ToolInput(tag="in_cell_line", input_type=Int(optional=True), prefix="--cell-line", doc=InputDocumentation(doc="The name of the cell line to be used for copy number\nvariation normalization. Must match one of the column\nnames in the file provided by --cnv-norm. This option\nwill overwrite the default case where cell line names\nare inferred from the columns of the design matrix.")), ToolInput(tag="in_cnv_est", input_type=Int(optional=True), prefix="--cnv-est", doc=InputDocumentation(doc="Estimate CNV profiles from screening data. A BED file\nwith gene positions are required as input. The CNVs of\nthese genes are to be estimated and used for copy\nnumber bias correction.")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="Debug mode to output detailed information of the")), ToolInput(tag="in_norm_method", input_type=String(optional=True), prefix="--norm-method", doc=InputDocumentation(doc="Method for normalization, including 'none' (no\nnormalization), 'median' (median normalization,\ndefault), 'total' (normalization by total read\ncounts), 'control' (normalization by control sgRNAs\nspecified by the --control-sgrna option).")), ToolInput(tag="in_genes_var_modeling", input_type=Int(optional=True), prefix="--genes-varmodeling", doc=InputDocumentation(doc="The number of genes for mean-variance modeling.\nDefault 0.")), ToolInput(tag="in_permutation_round", input_type=Int(optional=True), prefix="--permutation-round", doc=InputDocumentation(doc="The rounds for permutation (interger). The permutation\ntime is (# genes)*x for x rounds of permutation.\nSuggested value: 10 (may take longer time). Default 2.")), ToolInput(tag="in_no_permutation_by_group", input_type=Boolean(optional=True), prefix="--no-permutation-by-group", doc=InputDocumentation(doc="By default, gene permutation is performed separately,\nby their number of sgRNAs. Turning this option will\nperform permutation on all genes together. This makes\nthe program faster, but the p value estimation is\naccurate only if the number of sgRNAs per gene is\napproximately the same.")), ToolInput(tag="in_max_sg_rna_per_gene_permutation", input_type=Int(optional=True), prefix="--max-sgrnapergene-permutation", doc=InputDocumentation(doc="Do not calculate beta scores or p vales if the number\nof sgRNAs per gene is greater than this number. This\nwill save a lot of time if some isolated regions are\ntargeted by a large number of sgRNAs (usually\nhundreds). Must be an integer. Default 100.")), ToolInput(tag="in_remove_outliers", input_type=Boolean(optional=True), prefix="--remove-outliers", doc=InputDocumentation(doc="Try to remove outliers. Turning this option on will\nslow the algorithm.")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Using multiple threads to run the algorithm. Default\nusing only 1 thread.")), ToolInput(tag="in_adjust_method", input_type=String(optional=True), prefix="--adjust-method", doc=InputDocumentation(doc="Method for sgrna-level p-value adjustment, including\nfalse discovery rate (fdr), holm's method (holm), or\npounds's method (pounds).")), ToolInput(tag="in_sg_rna_efficiency", input_type=File(optional=True), prefix="--sgrna-efficiency", doc=InputDocumentation(doc="An optional file of sgRNA efficiency prediction. The\nefficiency prediction will be used as an initial guess\nof the probability an sgRNA is efficient. Must contain\nat least two columns, one containing sgRNA ID, the\nother containing sgRNA efficiency prediction.")), ToolInput(tag="in_sg_rna_eff_name_column", input_type=File(optional=True), prefix="--sgrna-eff-name-column", doc=InputDocumentation(doc="The sgRNA ID column in sgRNA efficiency prediction\nfile (specified by the --sgrna-efficiency option).\nDefault is 0 (the first column).")), ToolInput(tag="in_sg_rna_eff_score_column", input_type=File(optional=True), prefix="--sgrna-eff-score-column", doc=InputDocumentation(doc="The sgRNA efficiency prediction column in sgRNA\nefficiency prediction file (specified by the --sgrna-\nefficiency option). Default is 1 (the second column).")), ToolInput(tag="in_update_efficiency", input_type=Boolean(optional=True), prefix="--update-efficiency", doc=InputDocumentation(doc="Iteratively update sgRNA efficiency during EM")), ToolInput(tag="in_bayes", input_type=Boolean(optional=True), prefix="--bayes", doc=InputDocumentation(doc="Use the experimental Bayes module to estimate gene")), ToolInput(tag="in_ppi_weighting", input_type=String(optional=True), prefix="--PPI-weighting", doc=InputDocumentation(doc="The weighting used to calculate PPI prior. If not\nprovided, iterations will be used.")), ToolInput(tag="in_negative_control", input_type=String(optional=True), prefix="--negative-control", doc=InputDocumentation(doc="The gene name of negative controls. The corresponding\nsgRNA will be viewed independently.\n")), ToolInput(tag="in_running_dot", input_type=String(), position=0, doc=InputDocumentation(doc="--debug-gene DEBUG_GENE")), ToolInput(tag="in_iteration_dot", input_type=String(), position=0, doc=InputDocumentation(doc="Optional arguments for the Bayes estimation of gene essentiality (experimental):")), ToolInput(tag="in_essentiality", input_type=String(), position=1, doc=InputDocumentation(doc="-p, --PPI-prior       Specify whether you want to incorporate PPI as prior"))], outputs=[ToolOutput(tag="out_output_prefix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_prefix", type_hint=File()), doc=OutputDocumentation(doc="The prefix of the output file(s). Default sample1."))], container="quay.io/biocontainers/mageck:0.5.9.4--py38hed8969a_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Mageck_Mle_V0_1_0().translate("wdl")

